@@ -12,7 +12,7 @@ from requests.auth import HTTPBasicAuth
 import yaml
 import time
 
-VERSION = '0.5.2'
+VERSION = '0.5.3'
 
 backliftURL = {}
 default_backliftURL = 'https://www.backlift.com/'
@@ -227,7 +227,7 @@ def read_api_key():
     return api_key
 
 
-def check_backlift_cfg(path, app_id, force=False):
+def check_backlift_cfg(path, force=False):
     filepath = os.path.join(path, backlift_cfg_folder)
 
     if os.path.exists(filepath) and not force:
@@ -237,7 +237,7 @@ def check_backlift_cfg(path, app_id, force=False):
 
 
 def setup_app(path, app_id, force=False):
-    filepath = check_backlift_cfg(path, app_id, force)
+    filepath = check_backlift_cfg(path, force)
 
     keyfile = open_create(os.path.join(filepath, backlift_appid_file), 'w')
     keyfile.write(app_id)
@@ -267,23 +267,18 @@ def get_app_meta(api_key, app_id):
 def create_app(path, api_key, name, template, force=False):
     try:
         # import pdb; pdb.set_trace()
+        check_backlift_cfg(path, force=force)
+
         headers = {'x-requested-with': 'BackliftCLI',
                    'x-cli-version': VERSION}
 
-        r = requests.get(backliftURL['checkname'] % name, 
-                          auth=HTTPBasicAuth('api', api_key), 
-                          verify=False, headers=headers)
-        check_response(r)
-
-        app_id = json.loads(r.text)['_id']
-        check_backlift_cfg(path, app_id, force=force)
-
         r = requests.post(backliftURL['create'], 
                           data={'appname': name, 'template': template},
                           auth=HTTPBasicAuth('api', api_key), 
                           verify=False, headers=headers)
         check_response(r)
 
+        app_id = json.loads(r.text)['_id']
         setup_app(path, app_id, force=force)
 
         return app_id
